EventOrInitial

Enum EventOrInitial 

pub enum EventOrInitial<T> {
    Event(T),
    InitialMessage(Message),
}
Available on crate feature event-stream only.
Wrapper for event stream items that may include an initial-request message. This is used internally to allow initial messages to flow through the signing pipeline.

Variants



Event(T)

A regular event that needs marshalling and signing



InitialMessage(Message)

An initial-request message that’s already marshalled, just needs signing