ShapeId

Struct ShapeId 

pub struct ShapeId { /* private fields */ }
A Smithy Shape ID.

Shape IDs uniquely identify shapes in a Smithy model.

  • fqn is "smithy.example#Foo"
  • namespace is "smithy.example"
  • shape_name is "Foo"

Implementations

Source

impl ShapeId

pub const fn from_static( fqn: &'static str, namespace: &'static str, shape_name: &'static str, ) -> Self

Creates a ShapeId from a static string at compile time.

This is used for const initialization of prelude schemas.

pub fn new_from_parts( namespace: impl Into<Cow<'static, str>>, shape_name: impl Into<Cow<'static, str>>, ) -> Self

Creates a new ShapeId from a namespace and a shape_name.

Examples
use aws_smithy_schema::ShapeId;

let shape_id = ShapeId::new("smithy.api#String");
pub fn new_from_fqn(fqn: impl Into<Cow<'static, str>>) -> Option<Self>

Creates a new ShapeId from a fully qualified name.

pub fn new(fqn: impl Into<Cow<'static, str>>) -> Self

Creates a new ShapeId from a fully qualified name.

pub fn as_str(&self) -> &str

Returns the string representation of this ShapeId.

pub fn namespace(&self) -> &str

Returns the namespace portion of the ShapeId.

Examples
use aws_smithy_schema::ShapeId;

let shape_id = ShapeId::new("smithy.api#String");
assert_eq!(shape_id.namespace(), "smithy.api");
pub fn shape_name(&self) -> &str

Returns the shape name portion of the ShapeId.

Examples
use aws_smithy_schema::ShapeId;

let shape_id = ShapeId::new("smithy.api#String");
assert_eq!(shape_id.shape_name(), "String");
pub fn member_name(&self) -> Option<&str>

Returns the member name if this is a member shape ID.

Examples
use aws_smithy_schema::ShapeId;

let shape_id = ShapeId::new("com.example#MyStruct$member");
assert_eq!(shape_id.member_name(), Some("member"));